==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ron/db/dbutils.php <==
<?php
/**
 * stanislav.elbl, 19.02.2021
 */

namespace Ron\DB;

use Ron\StringUtils;

class DBUtils
{
    /**
     * Vraci hodnotu prvniho pole prvniho zaznamu. Pokud neni zadny zaznam nacten, vraci false.
     * V pripade ze je $returnRow true, vraci cely nacteny radek
     * @param Database $database
     * @param string $sql
     * @param Parameters $params
     * @param bool $returnRow
     * @return mixed
     * @throws DBException
     */
    static function getSqlValue($database, $sql, $params = null, $returnRow = false)
    {
        $cursor = $database ->getSqlResult($sql, $params);

        $row = $cursor ->fetch();
        $cursor ->close();

        if ($returnRow) {
            return $row;
        }

        return $row ? $row[0] : false;
    }


    /**
     * @param Database $database
     * @param string $format
     * @param mixed $dbValue
     * @return null|string
     */
    static function getFormatedValue($database, $format, $dbValue)
    {
        switch ($format)
        {
            case 'date' :
            case 'time' :
            case 'datetime' :
            case 'year' :
            case 'finedate' :
            case 'finedatetime' :
            case 'weektimestamp' :
                return StringUtils::format($format, $database ->stringToTimestamp($dbValue));

            case 'timestamp' :  // if ($data) return date('j.n.Y', $data); else return NULL;  // pozor! StringUtils vraci pro timestamp i cas!
                return StringUtils::format('date', $dbValue);
            case 'fulltimestamp' :
                return StringUtils::format('timestamp', $dbValue);

            case 'anone':       //return Ron\ronText($data ? 'Str_Yes' : 'Str_No');
            case 'int' :
                return StringUtils::format($format, $dbValue);

            case 'kc' :
            case 'curr' :
            case 'float' :
            case 'number0' :
            case 'number1' :
            case 'number_1' :
            case 'number2' :
            case 'number_2' :
                return StringUtils::format($format, StringUtils::stringToFloat($dbValue));

            case 'hodiny' :     //return isset($data) ? \Ron\DateUtils::minutesToString(\Ron\StringUtils::stringToFloat($data) * 60) : '';
            case 'minuty' :     //return isset($data) ? \Ron\DateUtils::minutesToString(\Ron\StringUtils::stringToFloat($data)) : '';
                return StringUtils::format($format, StringUtils::stringToFloat($dbValue));

            case 'sekundy' :    //return isset($data) ? \Ron\DateUtils::secondsToString(\Ron\StringUtils::stringToFloat($data)) : ''; // int => cas ve formatu h:m:s
                return StringUtils::format($format, StringUtils::stringToFloat($dbValue));

            case 'timeofday' :  //if ($data) return \Ron\DateUtils::minutesToString(db_stringtotimeofday($data) * 60); else return NULL; // datum v db formatu - pouze cas
                return StringUtils::format($format, $database ->stringToTimeOfDay($dbValue));

            case 'dump' :
                return var_export($dbValue, true);

            default :
                if (!isset($dbValue)) return '';
                if ($format) return StringUtils::htmlTextConvert(sprintf($format, $dbValue));
                return StringUtils::htmlTextConvert($dbValue);
        }
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ron/db/dbutils.php <==
<?php
/**
 * stanislav.elbl, 19.02.2021
 */

namespace Ron\DB;

use Ron\StringUtils;

class DBUtils
{
    /**
     * Vraci hodnotu prvniho pole prvniho zaznamu. Pokud neni zadny zaznam nacten, vraci false.
     * V pripade ze je $returnRow true, vraci cely nacteny radek
     * @param Database $database
     * @param string $sql
     * @param Parameters $params
     * @param bool $returnRow
     * @return mixed
     * @throws DBException
     */
    static function getSqlValue($database, $sql, $params = null, $returnRow = false)
    {
        $cursor = $database ->getSqlResult($sql, $params);

        $row = $cursor ->fetch();
        $cursor ->close();

        if ($returnRow) {
            return $row;
        }

        return $row ? $row[0] : false;
    }


    /**
     * @param Database $database
     * @param string $format
     * @param mixed $dbValue
     * @return null|string
     */
    static function getFormatedValue($database, $format, $dbValue)
    {
        switch ($format)
        {
            case 'date' :
            case 'time' :
            case 'fulltime' :
            case 'datetime' :
            case 'year' :
            case 'finedate' :
            case 'finedatetime' :
            case 'weektimestamp' :
                return StringUtils::format($format, $database ->stringToTimestamp($dbValue));

            case 'timestamp' :  // if ($data) return date('j.n.Y', $data); else return NULL;  // pozor! StringUtils vraci pro timestamp i cas!
                return StringUtils::format('date', $dbValue);
            case 'fulltimestamp' :
                return StringUtils::format('timestamp', $dbValue);

            case 'anone':       //return Ron\ronText($data ? 'Str_Yes' : 'Str_No');
            case 'int' :
                return StringUtils::format($format, $dbValue);

            case 'kc' :
            case 'curr' :
            case 'float' :
            case 'number0' :
            case 'number1' :
            case 'number_1' :
            case 'number2' :
            case 'number_2' :
            case 'number3' :
            case 'number_3' :
                return StringUtils::format($format, StringUtils::stringToFloat($dbValue));

            case 'hodiny' :     //return isset($data) ? \Ron\DateUtils::minutesToString(\Ron\StringUtils::stringToFloat($data) * 60) : '';
            case 'minuty' :     //return isset($data) ? \Ron\DateUtils::minutesToString(\Ron\StringUtils::stringToFloat($data)) : '';
                return StringUtils::format($format, StringUtils::stringToFloat($dbValue));

            case 'sekundy' :    //return isset($data) ? \Ron\DateUtils::secondsToString(\Ron\StringUtils::stringToFloat($data)) : ''; // int => cas ve formatu h:m:s
                return StringUtils::format($format, StringUtils::stringToFloat($dbValue));

            case 'timeofday' :  //if ($data) return \Ron\DateUtils::minutesToString(db_stringtotimeofday($data) * 60); else return NULL; // datum v db formatu - pouze cas
                return StringUtils::format($format, $database ->stringToTimeOfDay($dbValue));

            case 'longtext' :
                return StringUtils::longTextToHtml($dbValue, true);

            case 'dump' :
                return var_export($dbValue, true);

            default :
                if (!isset($dbValue)) {
                    return '';
                }
                return $format
                    ? StringUtils::htmlTextConvert(sprintf($format, $dbValue))
                    : StringUtils::htmlTextConvert($dbValue);
        }
    }
}
